pub struct Odd<G: KeyPiece>(/* private fields */);Expand description
An odd number of type G. It is never zero, so it is stored as a NonZero,
which lets Option use zero to represent None and makes Option<Odd<G>>
the same size as G.
Implementations
Sourceimpl<G: KeyPiece> Odd<G>
impl<G: KeyPiece> Odd<G>
Sourcepub unsafe fn new_unchecked(value: G) -> Self
pub unsafe fn new_unchecked(value: G) -> Self
Sourcepub fn wrapping_next(self) -> Even<G>
pub fn wrapping_next(self) -> Even<G>
The even number after this one. The largest value of G wraps around
to zero.